/*
 * Smart GWT (GWT for SmartClient)
 * Copyright 2008 and beyond, Isomorphic Software, Inc.
 *
 * Smart GWT is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version 3
 * as published by the Free Software Foundation.  Smart GWT is also
 * available under typical commercial license terms - see
 * http://smartclient.com/license
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 */
/* sgwtgen */
 
package com.smartgwt.client.ai;


import com.smartgwt.client.event.*;
import com.smartgwt.client.core.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.Record;
import com.smartgwt.client.data.events.*;
import com.smartgwt.client.browser.window.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.ai.*;
import com.smartgwt.client.callbacks.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.bean.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.ai.*;
import com.smartgwt.client.widgets.events.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.tile.events.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.grid.events.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.layout.events.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.tour.*;
import com.smartgwt.client.widgets.notify.*;
import com.smartgwt.client.widgets.rte.*;
import com.smartgwt.client.widgets.rte.events.*;
import com.smartgwt.client.widgets.ace.*;
import com.smartgwt.client.widgets.ace.events.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.tree.events.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.calendar.events.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.notify.*;
import com.smartgwt.client.widgets.drawing.*;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.google.gwt.event.shared.*;
import com.google.gwt.dom.client.Element;
import com.google.gwt.user.client.ui.Widget;
import com.google.gwt.core.client.JavaScriptObject;

import com.smartgwt.client.util.*;
import com.smartgwt.client.util.events.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.util.workflow.Process; // required to override java.lang.Process
import com.smartgwt.client.util.tour.*;


/**
 * Represents a request to AI for UI elements.
 */
@BeanFactory.FrameworkClass
public class BuildUIViaAIRequest extends BuildViaAIRequest {

    public static BuildUIViaAIRequest getOrCreateRef(JavaScriptObject jsObj) {
        if (jsObj == null) return null;

        final RefDataClass existingObj = RefDataClass.getRef(jsObj);

        if (existingObj instanceof BuildUIViaAIRequest) {
            existingObj.setJsObj(jsObj);
            return (BuildUIViaAIRequest)existingObj;
        } else

        {
            return new BuildUIViaAIRequest(jsObj);
        }
    }
        


    public BuildUIViaAIRequest(){
        
    }

    public BuildUIViaAIRequest(JavaScriptObject jsObj){
        
        setJavaScriptObject(jsObj);
    }



    // ********************* Properties / Attributes ***********************

    /**
     * The list of allowed UI types. <p> A "UI type" string is usually not the same as the corresponding Smart GWT component
     * type name.
     *
     * @param allowedUITypes New allowedUITypes value. Default value is null
     * @return {@link com.smartgwt.client.ai.BuildUIViaAIRequest BuildUIViaAIRequest} instance, for chaining setter calls
     */
    public BuildUIViaAIRequest setAllowedUITypes(String... allowedUITypes) {
        return (BuildUIViaAIRequest)setAttribute("allowedUITypes", allowedUITypes);
    }

    /**
     * The list of allowed UI types. <p> A "UI type" string is usually not the same as the corresponding Smart GWT component
     * type name.
     *
     * @return Current allowedUITypes value. Default value is null
     */
    public String[] getAllowedUITypes()  {
        return com.smartgwt.client.util.ConvertTo.arrayOfString(getAttributeAsJavaScriptObject("allowedUITypes"));
    }
    

    /**
     * The custom validation routine to use. If this validator is supplied, but <code>"custom"</code> is not included among the
     * {@link com.smartgwt.client.ai.BuildUIViaAIRequest#getValidationTypes validationTypes}, then it is implicitly assumed
     * that custom validation will be performed last.
     *
     * @param customValidator New customValidator value. Default value is null
     * @return {@link com.smartgwt.client.ai.BuildUIViaAIRequest BuildUIViaAIRequest} instance, for chaining setter calls
     */
    public BuildUIViaAIRequest setCustomValidator(BuildUIViaAICustomValidator customValidator) {
        return (BuildUIViaAIRequest)setAttribute("customValidator", customValidator);
    }
    

    /**
     * The maximum numnber of re-attempts to have the AI fix a validation error.
     *
     * @param maxValidationRetries New maxValidationRetries value. Default value is 1
     * @return {@link com.smartgwt.client.ai.BuildUIViaAIRequest BuildUIViaAIRequest} instance, for chaining setter calls
     */
    public BuildUIViaAIRequest setMaxValidationRetries(Integer maxValidationRetries) {
        return (BuildUIViaAIRequest)setAttribute("maxValidationRetries", maxValidationRetries);
    }

    /**
     * The maximum numnber of re-attempts to have the AI fix a validation error.
     *
     * @return Current maxValidationRetries value. Default value is 1
     */
    public Integer getMaxValidationRetries()  {
        return getAttributeAsInt("maxValidationRetries");
    }
    

    /**
     * The request from the user describing what UI they would like the AI to build.
     *
     * @param userAIRequest New userAIRequest value. Default value is null
     * @return {@link com.smartgwt.client.ai.BuildUIViaAIRequest BuildUIViaAIRequest} instance, for chaining setter calls
     */
    public BuildUIViaAIRequest setUserAIRequest(UserAIRequest userAIRequest) {
        return (BuildUIViaAIRequest)setAttribute("userAIRequest", userAIRequest == null ? null : userAIRequest.getJsObj());
    }

    /**
     * The request from the user describing what UI they would like the AI to build.
     *
     * @return Current userAIRequest value. Default value is null
     */
    public UserAIRequest getUserAIRequest()  {
        return UserAIRequest.getOrCreateRef(getAttributeAsJavaScriptObject("userAIRequest"));
    }
    

    /**
     * The types of validation to use on AI-generated JS code, in the order in which they should be applied.
     *
     * @param validationTypes New validationTypes value. Default value is ["default"]
     * @return {@link com.smartgwt.client.ai.BuildUIViaAIRequest BuildUIViaAIRequest} instance, for chaining setter calls
     */
    public BuildUIViaAIRequest setValidationTypes(BuildUIViaAIValidationType... validationTypes) {
        return (BuildUIViaAIRequest)setAttribute("validationTypes", validationTypes);
    }

    /**
     * The types of validation to use on AI-generated JS code, in the order in which they should be applied.
     *
     * @return Current validationTypes value. Default value is ["default"]
     */
    public BuildUIViaAIValidationType[] getValidationTypes()  {
        final String[] strings = getAttributeAsStringArray("validationTypes");
        return EnumUtil.getEnums(BuildUIViaAIValidationType.values(), strings, strings == null ? null : new BuildUIViaAIValidationType[strings.length]);
    }
    

    // ********************* Methods ***********************

    // ********************* Static Methods ***********************

    // ***********************************************************

}
